@@ -142,6 +142,22 @@ void corner_collision(  Uint8 xblock, Uint8 yblock)
   }
 }
 
+void ResetLevels() {
+	for (i=0;i<=NUMBER_OF_LEVELS[levelset];i++) {
+		int x,y;
+		
+		finished[i]=0;
+		for (x=0; x<20; x++) {
+			for (y=0; y<15; y++) {
+				if (levelset == 0)
+					map[i][y][x] = origMap[i][y][x];
+				else
+					map[i][y][x] = origMap2[i][y][x];
+			}
+		}
+	}
+}
+
 /**
  * If players p1 and p2 collide, moves them out of the collision and makes them bounce.
  */
@@ -970,19 +986,7 @@ void nextlevel() //selects the next level at random
     levels_completed++;
   } else {
     // reset all levels, if each level has been played one time
-    for (i=0;i<=NUMBER_OF_LEVELS[levelset];i++) {
-      int x,y;
-
-      finished[i]=0;
-      for (x=0; x<20; x++) {
-        for (y=0; y<15; y++) {
-	  if (levelset == 0)
-            map[i][y][x] = origMap[i][y][x];
-	  else 
-            map[i][y][x] = origMap2[i][y][x];
-        }
-      }
-    }
+    ResetLevels();
     quit=0;
     levelnum=abrand(0,NUMBER_OF_LEVELS[levelset]-1);
   }
@@ -1119,7 +1123,9 @@ void LoadSound()
 	if (sound) {
 		sprintf(text,"%s/sound/lizard.mod",DATAPATH);
 		music = Mix_LoadMUS(text);
-		if (music==NULL) {printf("COULD NOT LOAD MUSIC\n");ComplainAndExit();}
+		if (music==NULL) {
+			printf("COULD NOT LOAD MUSIC\n");
+		}
 		sprintf(text,"%s/sound/%s",DATAPATH,"explode.wav");
 		explode_sound = Mix_LoadWAV_RW(SDL_RWFromFile(text, "rb"), 1);
 		sprintf(text,"%s/sound/%s",DATAPATH,"winlevel.wav");
@@ -1171,23 +1177,11 @@ int main(int argc, char *argv[])
     SDL_Delay(3000);
     SDL_UpdateRect(Screen,50,380,700,90);
   }
-  for (i=0;i<=NUMBER_OF_LEVELS[levelset];i++) {
-    int x,y;
-    
-    finished[i]=0;
-    for (x=0; x<20; x++) {
-	for (y=0; y<15; y++) {
-	    if (levelset == 0)
-		map[i][y][x] = origMap[i][y][x];
-	    else
-		map[i][y][x] = origMap2[i][y][x];
-	}
-    }
-  }
   // select game mode
   Menu();
   while (mode!=3)
   {
+    ResetLevels();
     levelnum=abrand(0,NUMBER_OF_LEVELS[levelset]-1);
     sprintf(text,"BumpRace: Level #%d",levelnum);
     SDL_WM_SetCaption(text,"BumpRace");
@@ -1233,7 +1227,7 @@ int main(int argc, char *argv[])
         checks_common();
         timing();
         blit_lifetime();
-	Update();
+		Update();
       }
       //end of game loop
       if ((user[0].completed)||(user[playernum-1].completed))
