@@ -1,13 +1,17 @@
-#include <bumprace.h>
-#include "IMG.h"
-#include "particles.h"
+#include "bumprace.h"
+#include "SDL_image.h"
+#include <stdlib.h>
+#include <string.h>
 
 #define PATHNUM 8
 #define BPP 0
 #define RECTS_NUM 40000
+#ifndef DATADIR
+#define DATADIR "BumpRace.app/Contents/Resources/data"
+#endif
 char DATAPATH[200]=DATADIR;
 const char PATH[PATHNUM][200]={DATADIR,".","data","/usr/local/share/bumprace"
-,"/usr/lib/bumprace","../data","/usr/share/bumprace",DATADIR};
+,"/usr/lib/bumprace","../data","/usr/share/bumprace", DATADIR};
 SDL_Surface *Screen,*BackBuffer,*fadebuffer;
 SDL_Rect blitrect,blitrects[RECTS_NUM];
 int blitrects_num=0;
@@ -80,7 +84,7 @@ void init_SDL()  // sets the video mode
   int bpp=BPP;
   const SDL_VideoInfo *info;
 
-  if ( SDL_Init(SDL_INIT_VIDEO|SDL_INIT_TIMER) < 0 ) {ComplainAndExit();}
+  if ( SDL_Init(SDL_INIT_VIDEO|SDL_INIT_TIMER|SDL_INIT_AUDIO) < 0 ) {ComplainAndExit();}
   info = SDL_GetVideoInfo();
   if (info->vfmt->BitsPerPixel==8) bpp=16;
   atexit(SDL_Quit);
@@ -194,35 +198,30 @@ int DoLine (SDL_Surface *Surface, Sint32 X1, Sint32 Y1, Sint32 X2, Sint32 Y2, Ui
    return 0;
 }
 
-// The user's line drawing function
-void Line(Sint32 X1, Sint32 Y1, Sint32 X2, Sint32 Y2, Uint32 Color)
-{
-   Sint32 temp;
-
-/*
-
-   // Make sure X1 is before X2 
-   if (X2 < X1){
-      temp = X2;
-      X2 = X1;
-      X1 = temp;
-   }
-   // Make sure Y1 is before Y2 
-   if (Y2 < Y1){
-      temp = Y2;
-      Y2 = Y1;
-      Y1 = temp;
-   }
-*/
-   lock(Screen);
-
-   /* Draw the line */
-   DoLine(Screen, X1, Y1, X2, Y2, Color, &PutPixel);
-   unlock(Screen);
-}
-
 void fadeout()
 {
+	int y;
+	SDL_Rect rect;
+	Uint32 time;
+
+	rect.x = 0;
+	rect.w = 800;
+	rect.h = 1;
+	for (y=0; y<600; y+=2) {
+		time = SDL_GetTicks();
+		rect.y = y;
+		SDL_FillRect(Screen, &rect, SDL_MapRGB(Screen->format, 0,0,0));
+		SDL_UpdateRects(Screen, 1, &rect);
+		if (time == SDL_GetTicks())
+			SDL_Delay(1);
+	}
+	for (y=599; y>0; y-=2) {
+		rect.y = y;
+		SDL_FillRect(Screen, &rect, SDL_MapRGB(Screen->format, 0,0,0));
+		SDL_UpdateRects(Screen, 1, &rect);
+	}
+	
+	/*
   int x,y;
   
   if (dofadeout==0) return;
@@ -246,15 +245,12 @@ void fadeout()
     }
     unlock();
     Update();
-  }
+  }*/
 }
 
 void Update()
 {
-  if (NullParticle > 0)
-    SDL_UpdateRect(Screen, 0,0,0,0);
-  else
-     SDL_UpdateRects(Screen,blitrects_num,blitrects);
+  SDL_UpdateRects(Screen,blitrects_num,blitrects);
   blitrects_num=0;
 }
 
@@ -262,8 +258,6 @@ void AddRect(int x1, int y1, int x2, int y2)
 {
   int temp;
 
-  if (NullParticle > 0)
-    return;
    /* Make sure X1 is before X2 */
    if (x2 < x1){
       temp = x2;
@@ -292,9 +286,6 @@ void AddRect(int x1, int y1, int x2, int y2)
 
 void AddThisRect(SDL_Rect blitrect)
 {
-  if (NullParticle > 0)
-    return;
-
     blitrects[blitrects_num]=blitrect;
     if (++blitrects_num>=RECTS_NUM-2)
         {printf("Too many blits!\n");blitrects_num--;Update();}
@@ -313,7 +304,6 @@ void Blit(int Xpos,int Ypos,SDL_Surface *image)  //blits one GIF or BMP from the
   if (Ypos>=600) printf("WRONG BLIT: Ypos is too big! - %d\n",Ypos); else
   if ( SDL_BlitSurface(image, NULL, Screen, &blitrect) < 0 ) 
   {
-  
     SDL_FreeSurface(image);
     ComplainAndExit();
   }
@@ -426,7 +416,7 @@ int PutPixelC(SDL_Surface *Surface, Sint32 X, Sint32 Y, Uint32 Color)
     return 0;
 }
 
-int PutBackPixel(SDL_Surface *Surface, Sint32 X, Sint32 Y)
+void PutBackPixel(SDL_Surface *Surface, Sint32 X, Sint32 Y)
 {
     SDL_Rect rect;
     
@@ -437,38 +427,3 @@ int PutBackPixel(SDL_Surface *Surface, Sint32 X, Sint32 Y)
     SDL_BlitSurface(BackBuffer, &rect, Surface, &rect);
     AddThisRect(rect);
 }
-
-Uint32 GetPixel (SDL_Surface *Surface, Sint32 X, Sint32 Y)
-{
-
-   Uint8  *bits;
-   Uint32 Bpp;
-
-   
-   Bpp = Surface->format->BytesPerPixel;
-
-   bits = ((Uint8 *)Surface->pixels)+Y*Surface->pitch+X*Bpp;
-
-   // Get the pixel
-   switch(Bpp) {
-      case 1:
-         return *((Uint8 *)Surface->pixels + Y * Surface->pitch + X);
-         break;
-      case 2:
-         return *((Uint16 *)Surface->pixels + Y * Surface->pitch/2 + X);
-         break;
-      case 3: { // Format/endian independent 
-         Uint8 r, g, b;
-         r = *((bits)+Surface->format->Rshift/8);
-         g = *((bits)+Surface->format->Gshift/8);
-         b = *((bits)+Surface->format->Bshift/8);
-         return SDL_MapRGB(Surface->format, r, g, b);
-         }
-         break;
-      case 4:
-         return *((Uint32 *)Surface->pixels + Y * Surface->pitch/4 + X);
-         break;
-   }
-
-   return -1;
-}
