@@ -47,8 +47,8 @@ void help()  //prints the help & credits screeen
   PutString(Screen, 350, 195, "Lion Kimbro (particles) <SnowLion@sprynet.com>");
   PutString(Screen, 350, 220, "Graphics:");
   PutString(Screen, 350, 235, "Karl Bartel");
-  PutString(Screen, 500, 220, "Backgrounds:");
-  PutString(Screen, 500, 235, "Unknown (see AUTHORS)");
+  PutString(Screen, 500, 220, "Background:");
+  PutString(Screen, 500, 235, "tozzie (www.tozzie-designs.com)");
 
   PutString(Screen, 350, 265, "Packaging:");
   PutString(Screen, 350, 280, "Christian T. Steigies (debian)"),
