@@ -66,8 +66,7 @@ void ReadOptions()
 void FinalScore()
 {
     char Name[200]="",text[200];
-    int ch=SDLK_a,a;
-    SDL_Rect rect;
+	int a;
     FILE *file;
 
     if (Score>Hiscore[9]) {
@@ -77,26 +76,9 @@ void FinalScore()
     XCenteredString(Screen, 250, text);
     XCenteredString(Screen, 300, "Enter Your Name:");
     Update();
-    rect.x=0;
-    rect.y=350;
-    rect.w=800;
-    rect.h=100;
-    SDL_EventState(SDL_KEYDOWN, SDL_ENABLE);
-    while ((ch!=SDLK_RETURN)&&(SDL_WaitEvent(&event))) {
-		SDL_PollEvent(&event);
-		if (event.type==SDL_KEYDOWN) {
-			ch=event.key.keysym.unicode;
-			sprintf(Name,"%s%c",Name,ch);
-			if (ch=='\b') Name[strlen(Name)-2]='\0';
-			//printf("%s  -  %c\n",Name,ch);
-			SDL_BlitSurface( back, &rect, Screen, &rect);
-			PutString(Screen,400-SFont_TextWidth(Name)/2,350,Name);
-			AddThisRect(rect);
-			Update();
-		}
-		SDL_Delay(10);
-    }
-    Name[strlen(Name)-1]='\0';
+	SDL_EventState(SDL_KEYUP, SDL_ENABLE);
+	SDL_EventState(SDL_KEYDOWN, SDL_ENABLE);
+	SFont_Input(Screen, 350, 350, 200, Name);
     if (strcmp(Name,"")==0) strcpy(Name,"Anonymous Coward");
     for (i=0;i<10;i++) {
 	if (Score>Hiscore[i]) {
